@@ -202,8 +202,7 @@ double attr_hidden
     int ione = 1, n = LENGTH(GET_SLOT(x, lme4_ySym)), p = LENGTH(fixef);
     double *X = REAL(GET_SLOT(x, lme4_XSym)), one[] = {1,0};
     CHM_SP Zt = AS_CHM_SP(GET_SLOT(x, lme4_ZtSym));
-    CHM_DN chb = AS_CHM_DN(ranef),
-	chv = M_numeric_as_chm_dense(alloca(sizeof(cholmod_dense)), val, n);
+    CHM_DN chb = AS_CHM_DN(ranef), chv = N_AS_CHM_DN(val, n);
     R_CheckStack();	
 
     mer_secondary(x);
@@ -404,8 +403,7 @@ internal_betab_update(int p, int q, double sigma, cholmod_factor *L,
 		      double RZX[], double RXX[], double betahat[],
 		      double bhat[], double betanew[], double bnew[])
 {
-    CHM_DN chb,
-	chbnew = M_numeric_as_chm_dense(alloca(sizeof(cholmod_dense)), bnew, q);
+    CHM_DN chb, chbnew = N_AS_CHM_DN(bnew, q);
     int *perm = (int *)L->Perm;
     int j, ione = 1;
     double m1[] = {-1,0}, one[] = {1,0}, ans = 0;
